import { Component, OnInit } from "@angular/core";
import { remote } from "electron";
import { Infractor } from "../citation-wizard/model/infractor";
import { Citation } from "../citation-wizard/model/citation";
import { Vehicle } from "./model/vehicle";
import { AdditionalComments } from "./model/additional-comments";
import { Infraction } from "./model/infraction";
import { SafeUrl, DomSanitizer } from '@angular/platform-browser';
@Component({
  selector: "wizard",
  template: `
  <reaxium>
  <form-wizard>
    <wizard-step [title]="'Infractor'" [imagePath]="getImage('infractor')" (onNext)="onStepChange($event)">
         <infractor [infractor]="citation.infractor"></infractor>
    </wizard-step>
  
    <wizard-step [title]="'Vehicle'" [imagePath]="getImage('vehicle')" (onNext)="onStepChange($event)">
      <vehicle [vehicle]="citation.vehicle"></vehicle>
    </wizard-step>
  
    <wizard-step [title]="'Infractions'"  [imagePath]="getImage('infractions')" (onNext)="onStepChange($event)">
      <infraction (emittedInfractions)="getInfractionsChanged($event)"  [infractions]="citation.infractions"></infraction>
    </wizard-step>
  
    <wizard-step [title]="'Comments'" [imagePath]="getImage('comments')" (onNext)="onStepChange($event)">
      <additional-comment
        (emittedAdditionalComments)="getCommentsChanged($event)"
        [additionalComments]="citation.additionalComments"
      ></additional-comment>
    </wizard-step>
  
    <wizard-step [title]="'Summary'" [imagePath]="getImage('summary')" (onComplete)="onStepChange($event)">
      <summary [citation]="citation"></summary>
    </wizard-step>
  
  </form-wizard>
  </reaxium>`
})
export class CitationWizardComponent implements OnInit {

  //This citation object is used by all child components
  citation: Citation;

  rootDir: string = __dirname;

  argunentsReceived = [];

  constructor(private domSanitizer:DomSanitizer) { }

  ngOnInit(): void {
    console.log("Wizard initialized", remote);

    //retrieve the command console arguments 
    this.argunentsReceived = remote.process.argv;

    console.log(this.argunentsReceived);

    //get from the arguments the data related to the infractor
    let infractor: Infractor = this.getInfractorFormArguments(this.argunentsReceived);

    // create a new citation object
    this.initializeACitation(infractor);
  }

  getImage(name:string):SafeUrl{
   let url: SafeUrl = {};
    switch(name){
      case 'infractor':
       url = this.domSanitizer.bypassSecurityTrustUrl(this.rootDir+'/img/man-user.png');
      break;
      case 'vehicle':
      url = this.domSanitizer.bypassSecurityTrustUrl(this.rootDir+'/img/car.png');
     break;
     case 'infractions':
      url = this.domSanitizer.bypassSecurityTrustUrl(this.rootDir+'/img/infraction.png');
     break;
     case 'comments':
      url = this.domSanitizer.bypassSecurityTrustUrl(this.rootDir+'/img/comment.png');
     break;
     case 'summary':
     url = this.domSanitizer.bypassSecurityTrustUrl(this.rootDir+'/img/summary.png');
    break;
    }
    return url;
  }

  onStepChange(event: any) {
    console.log(event);
  }

  onComplete(event: any) {
    console.log(event);
    return true;
  }

  getInfractorFormArguments(consoleArguments: any[]): Infractor {
    const infractorJSON = consoleArguments[consoleArguments.length - 1];
    let infractor: Infractor;
    try {
     // const dataTest =  '{ "name": "eduardo", "lastName": "luttinger" }';
      console.log('infractorJSON: '+infractorJSON);
      
      const jsonFixed = infractorJSON.replace('\n','').replace(/'/g, '"');;
      
      console.log('jsonFixed: '+jsonFixed);
      
      infractor = <Infractor>JSON.parse(jsonFixed);
    } catch (error) {
      infractor = <Infractor>{};
      console.log('Errorrrrrr: ',error);
    }
    
    return infractor;
  }


  initializeACitation(infractor: Infractor) {
    console.log('infractor que se recibe');
    this.citation = <Citation>{};
    this.citation.infractor = infractor;
    this.citation.vehicle = <Vehicle>{};
    this.citation.additionalComments = <AdditionalComments[]>[];
    this.citation.infractions = <Infraction[]>[];
    console.log('Citation just  loaded: ', this.citation);
  }


  getInfractionsChanged(infractions: Infraction[]) {
    this.citation.infractions = infractions.filter(infraction => infraction.selected);
  }

  getCommentsChanged(comments: AdditionalComments[]) {
    this.citation.additionalComments = comments.filter(comment => comment.comment != '');
  }


}
