
import { Component, OnInit, Input } from '@angular/core';
import { Citation } from './model/citation';
@Component({
   selector: 'summary',
   template: `<div>
   <h2><b>Summary</b></h2>
   <hr>
   <div>
     <h4><b class="primaryTitle">Infractor Data</b></h4>
     <div><b>Name: </b><span class="text-capitalize">{{ citation.infractor.name }}</span></div>
     <div><b>Last Name: </b> <span class="text-capitalize">{{ citation.infractor.lastName }}</span></div>
     <div><b>License Number: </b> <span class="text-capitalize">{{ citation.infractor.cardId }}</span></div>
     <div><b>Address: </b> <span class="text-capitalize">{{ citation.infractor.address }}</span></div>
   </div>
   <br>
   <div>
     <h4><b class="primaryTitle">Vehicle Data</b></h4>
     <div><b>Tag Number: </b><span class="text-uppercase">{{ citation.vehicle.tagNumber }}</span></div>
     <div><b>Brand: </b> <span class="text-capitalize">{{ citation.vehicle.brand }}</span></div>
     <div><b>Model: </b> <span class="text-capitalize">{{ citation.vehicle.model }}</span></div>
     <div><b>Year: </b> {{ citation.vehicle.year }}</div>
     <div><b>Color: </b> <span class="text-capitalize">{{ citation.vehicle.color }}</span></div>
   </div>
   <br>
   <div>
     <h4><b class="primaryTitle">Infractions</b></h4>
     <ul class="list-unstyled">
       <li *ngFor="let infraction of citation.infractions">
           {{infraction.name}} <span class="float-right">\${{infraction.amount}}.00</span>
       </li>
     </ul>
     <hr class="totalSeparator">
     <h5>
       <b>TOTAL <span class="float-right">\${{getInfractionsTotal()}}.00</span></b>
     </h5>
   </div>
   <br>
   <div>
     <h4><b class="primaryTitle">Additional Comments</b></h4>
     <ul>
       <li class="text-capitalize" *ngFor="let comment of citation.additionalComments">
         {{comment.comment}}
       </li>
     </ul>
   </div>
 
   <!-- Y aqui el resto del summary -->
 </div>
 `
})
export class SummaryComponent implements OnInit {
  
  @Input() citation: Citation;

  constructor(){}

  ngOnInit(): void {
      console.log('Summary Component initialized');
  }

  getInfractionsTotal()
  {
      let total = 0;
      if(this.citation.infractions.length > 0)
      {
          total = this.citation.infractions.reduce((sum, item) => sum + item.amount, 0);
      }
      return total;
  }
}