import { app, BrowserWindow, Menu, MenuItemConstructorOptions } from "electron";
import { enableLiveReload } from "electron-compile";
import * as url from "url";
import * as path from "path";

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let mainWindow: Electron.BrowserWindow | null;

let additionalWindow: Electron.BrowserWindow | null;

let mainMenuTemplate: MenuItemConstructorOptions[];

const isProductionModeOn = !process.execPath.match(/[\\/]electron/);

if (!isProductionModeOn) enableLiveReload();

const createWindow = async () => {
  // Create the browser window.
  mainWindow = new BrowserWindow();

  // and load the index.html of the app.
  mainWindow.loadURL(
    url.format({
      pathname: path.join(__dirname, "index.html"),
      protocol: "file",
      slashes: true
    })
  );

  // Emitted when the window is closed.
  mainWindow.on("closed", () => {
    mainWindow = null;
    app.quit();
  });

  mainMenuTemplate = createApplicationMenu();

  handleMenuOnMac();
  handlegDebugMenu();

  //add the menu
  const mainMenu = Menu.buildFromTemplate(mainMenuTemplate);
  //Inset the menu
  Menu.setApplicationMenu(mainMenu);
};

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on("ready", createWindow);

// Quit when all windows are closed.
app.on("window-all-closed", () => {
  // On OS X it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if (process.platform !== "darwin") {
    app.quit();
  }
});

app.on("activate", () => {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (mainWindow === null) {
    createWindow();
  }
});

//Create menu template
function createApplicationMenu(): MenuItemConstructorOptions[] {
  return [
    {
      label: "Mobile Citation",
      submenu: [
        {
          label: "Create a Citation",
          click() {
            console.log("Here most show the citation wizard");
            runAWindows("wizard", "Citation Wizard");
          }
        },
        {
          label: "Create a Crash Report",
          click() {
            console.log("Here should appear a crash report wizard");
          }
        },
        {
          role: "reload"
        },
        {
          label: "Quit",
          accelerator:
            process.platform.toString() == "darwin" ? "Command+Q" : "Ctrl+Q",
          click() {
            app.quit();
          }
        }
      ]
    }
  ];
}

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and import them here.
function runAWindows(navigateTo: string, windowTitle: string) {
  additionalWindow = new BrowserWindow({
    width: 800,
    height: 600,
    title: windowTitle
  });
  const navigation = url.format({
    pathname: path.join(__dirname, "index.html"),
    protocol: "file",
    slashes: true,
    hash: navigateTo
  });
  additionalWindow.loadURL(navigation);
  //additionalWindow.webContents.toggleDevTools();
}

function handleMenuOnMac() {
  console.log(process.platform.toString());
  if (process.platform.toString() == "darwin") {
    const emptyMenu: MenuItemConstructorOptions = {};
    mainMenuTemplate.unshift(emptyMenu);
  }
}

function handlegDebugMenu() {
  //if (!isProductionModeOn) {
  mainMenuTemplate.push({
    label: "Developer Tools",
    submenu: [
      {
        label: "Open Dev Console",
        accelerator:
          process.platform.toString() == "darwin" ? "Command+I" : "Ctrl+I",
        click(item, focusedWindow) {
          console.log(item);
          focusedWindow.webContents.toggleDevTools();
        }
      },
      {
        role: "reload"
      }
    ]
  });
  // }
}
